@@ -1,7 +1,7 @@
 //! Useful vector math implementations
 
 use num::Num;
-use std::ops::{Add, Sub};
+use std::{fmt, ops::{Add, Sub}};
 
 #[allow(unused)]
 
@@ -40,6 +40,12 @@ impl<T: Num> Sub for Vec2<T> {
     }
 }
 
+impl<T: Num + std::fmt::Display> fmt::Display for Vec2<T> {
+    fn fmt(&self, f: &mut fmt::Formatter) -> fmt::Result {
+        write!(f, "({}, {})", self.x, self.y)
+    }
+}
+
 
 #[cfg(test)]
 mod tests {
